DvaConnect class
Represents the return value of useDvaConnect.
Contains three optional properties:
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- props ↔ Props?
-
The Props instance for dispatching actions and navigation.
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
state
↔ Map<
String, StoreOfState> ? -
The current mapped state, where keys are namespace names
and values are the corresponding
StoreOfState.getter/setter pair - store ↔ Store?
-
The Store instance for accessing root state and subscribing to changes.
getter/setter pair
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited