MapState typedef
Type definition for a custom state mapping function.
Takes the root state map and returns a mapped/subset state map. Useful for transforming or selecting specific parts of the global state.
Implementation
typedef MapState = Map<String, StoreOfState> Function(
Map<String, StoreOfState> rootState);