flutter_dva_hooks library
Flutter Dva Hooks - A hook library built on top of flutter_hooks for Flutter Dva state management.
This library provides a set of hooks that allow you to use Dva state management in Flutter in a declarative, functional way. It includes hooks for connecting to the store, accessing props, and accessing the store instance.
Classes
- DvaConnect
- Represents the return value of useDvaConnect.
Functions
-
useDvaConnect(
{String? namespace, List< String> ? listenKeys, MapState? mapState, ShouldUpdate? shouldUpdate, VoidCallback? didMounted}) → DvaConnect - A hook that connects a widget to the Dva Store.
-
useDvaProps(
{String? namespace}) → Props -
A hook that retrieves only the
Propsinstance from the Dva Store. -
useDvaStore(
) → Store -
A hook that retrieves the
Storeinstance from the Dva Provider.